==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CalloutAnnotationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutAnnotationDescription } from "./CalloutAnnotationDescription";
/**
 * @hidden
 */
export let CalloutAnnotationDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutAnnotationDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutAnnotationDescriptionMetadata.a == null) {
                CalloutAnnotationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutAnnotationDescriptionMetadata.c(CalloutAnnotationDescriptionMetadata.a);
            }
            if (a.j(CalloutAnnotationDescriptionMetadata.a)) {
                return;
            }
            a.y(CalloutAnnotationDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("Text", "String");
            a.item("KeyRef", "(w:Key,wf:Key)DataRef");
            a.item("ContentRef", "(w:Content,wf:Content)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("FormatLabelRef", "(w:FormatLabel,wf:FormatLabel)MethodRef");
            a.item("TextColor", "Brush");
            a.item("Background", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
            a.item("BackgroundPaddingLeft", "Number:double");
            a.item("BackgroundPaddingTop", "Number:double");
            a.item("BackgroundPaddingRight", "Number:double");
            a.item("BackgroundPaddingBottom", "Number:double");
            a.item("BackgroundCornerRadius", "Number:double");
        }
        static d(a) {
            CalloutAnnotationDescriptionMetadata.b(a);
            a.aa("CalloutAnnotation", () => new CalloutAnnotationDescription());
            a.z("CalloutAnnotation", CalloutAnnotationDescriptionMetadata.a);
        }
    }
    CalloutAnnotationDescriptionMetadata.$t = /*@__PURE__*/ markType(CalloutAnnotationDescriptionMetadata, 'CalloutAnnotationDescriptionMetadata');
    CalloutAnnotationDescriptionMetadata.a = null;
    return CalloutAnnotationDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CalloutAnnotationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutAnnotationDescription } from "./CalloutAnnotationDescription";
/**
 * @hidden
 */
export let CalloutAnnotationDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutAnnotationDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutAnnotationDescriptionMetadata.a == null) {
                CalloutAnnotationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutAnnotationDescriptionMetadata.c(CalloutAnnotationDescriptionMetadata.a);
            }
            if (a.k(CalloutAnnotationDescriptionMetadata.a)) {
                return;
            }
            a.aa(CalloutAnnotationDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("Text", "String");
            a.item("KeyRef", "(w:Key,wf:Key)DataRef");
            a.item("ContentRef", "(w:Content,wf:Content)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("FormatLabelRef", "(w:FormatLabel,wf:FormatLabel)MethodRef");
            a.item("TextColor", "Brush");
            a.item("Background", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
            a.item("BackgroundPaddingLeft", "Number:double");
            a.item("BackgroundPaddingTop", "Number:double");
            a.item("BackgroundPaddingRight", "Number:double");
            a.item("BackgroundPaddingBottom", "Number:double");
            a.item("BackgroundCornerRadius", "Number:double");
        }
        static d(a) {
            CalloutAnnotationDescriptionMetadata.b(a);
            a.ac("CalloutAnnotation", () => new CalloutAnnotationDescription());
            a.ab("CalloutAnnotation", CalloutAnnotationDescriptionMetadata.a);
        }
    }
    CalloutAnnotationDescriptionMetadata.$t = /*@__PURE__*/ markType(CalloutAnnotationDescriptionMetadata, 'CalloutAnnotationDescriptionMetadata');
    CalloutAnnotationDescriptionMetadata.a = null;
    return CalloutAnnotationDescriptionMetadata;
})();
